@@ -1,7 +1,7 @@
 /*
  * options.h - Defines possible command line options
  *
- * Copyright (C) 2003 Brailcom, o.p.s.
+ * Copyright (C) 2003, 2006 Brailcom, o.p.s.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -17,44 +17,41 @@
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- *
- * $Id: options.h,v 1.7 2006/04/23 20:44:07 hanke Exp $
  */
 
-#include <getopt.h>
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
+#ifndef OPTIONS_H
+#define OPTIONS_H
 
-#define PACKAGE "speechd-up"
-#define VERSION "0.1"
-
-int LOG_LEVEL;
-char *LOG_FILE_NAME;
-
-int SPD_SPK_MODE;
 #define MODE_DAEMON 1
 #define MODE_SINGLE 0
 
-char *SPEAKUP_DEVICE;
-char *SPEAKUP_CODING;
+#define DEFAULT 0
+#define COMMAND_LINE 1
+#define CONFIG_FILE 2
 
-int PROBE_MODE;
-int DONT_INIT_TABLES;
-
-static struct option spd_long_options[] = {
-    {"run-daemon", 0, 0, 'd'},
-    {"run-single", 0, 0, 's'},
-    {"log-level", 1, 0, 'l'},
-    {"log-file", 1, 0, 'L'},
-    {"device", 1, 0, 'D'},
-    {"coding", 1, 0, 'c'},
-    {"synthesis", 1, 0, 'S'},
-    {"dont-init-tables", 0, 0, 't'},
-    {"probe", 0, 0, 'p'},
-    {"version", 0, 0, 'v'},
-    {"help", 0, 0, 0},
-    {0, 0, 0, 0}
+struct spd_options {
+	int log_level;
+	int log_level_set;
+	char *log_file_name;
+	int log_file_name_set;
+	int spd_spk_mode;
+	char *config_file_name;
+	char *speakup_device;
+	int speakup_device_set;
+	char *speakup_chartab;
+	int speakup_chartab_set;
+	char *speakup_characters;
+	int speakup_characters_set;
+	char *speakup_coding;
+	int speakup_coding_set;
+	char *language;
+	int language_set;
+	int probe_mode;
+	int dont_init_tables;
+	int dont_init_tables_set;
 };
 
-static char* spd_short_options = "dsvhptl:L:D:S:c:";
+void options_set_default(void);
+void options_parse(int argc, char *argv[]);
+
+#endif
